dgknght.app-lib.api-async


apply-body-fncljs

(apply-body-fn f)

Given a function that accepts a single argument, returns a transducing function that applies the given function either to the body of a response map or to each element in the body of the response map if the body is sequential.

This would be appropriate for option {:extract-body :after} or without the :extract-body option.

Given a function that accepts a single argument, returns a transducing
function that applies the given function either to the body of a
response map or to each element in the body of the response map if the
body is sequential.

This would be appropriate for option {:extract-body :after} or without
the :extract-body option.
raw docstring

apply-fncljs

(apply-fn f)

Given a function that accepts a single argument, returns a transducing function that applies the given function either to each value as a whole, or each element of each values if the value is sequential.

This would be appropriate for use with option {:extract-body :before}

Given a function that accepts a single argument, returns a transducing
function that applies the given function either to each value as a whole,
or each element of each values if the value is sequential.

This would be appropriate for use with option {:extract-body :before}
raw docstring

deletecljs

(delete path)
(delete path options)
(delete path resource options)

getcljs

(get path)
(get path criteria)
(get path criteria options)

multipart-paramscljs

(multipart-params req params)

patchcljs

(patch path resource)
(patch path resource options)

pathcljs


postcljs

(post path resource)
(post path resource options)

putcljs

(put path resource)
(put path resource options)

requestcljs

(request options)

cljdoc builds & hosts documentation for Clojure/Script libraries