(->sequential x)(assoc-if m k v)Performs an assoc if the specified value is not nil.
Performs an assoc if the specified value is not nil.
(assoc-unless m k v)Performs an assoc unless the map already contains the key
Performs an assoc unless the map already contains the key
(conj-to-last lists x)Given a list of lists, conjs the value x onto the last (as identified by the fn pop) inner list of the outer list
Given a list of lists, conjs the value x onto the last (as identified by the fn pop) inner list of the outer list
(deep-contains? data k)Given a data structure, returns a boolean value indicating whether or not the structure contains that specified key at any level of nesting.
Given a data structure, returns a boolean value indicating whether or not the structure contains that specified key at any level of nesting.
(deep-dissoc data k)Given a data structure, returns the same structure with the first found instance of the specified key removed
Given a data structure, returns the same structure with the first found instance of the specified key removed
(deep-get data k)Given a data structure, returns the value of the first found instance of the specified key.
Given a data structure, returns the value of the first found instance of the specified key.
(deep-update-in-if data k f)Given a data structure, returns the same structure with the value at the first instance of the specified key updated with the given function.
Given a data structure, returns the same structure with the value at the first instance of the specified key updated with the given function.
(derefable? v)Returns a boolean value indicating whether or not a value can be dereferenced.
Returns a boolean value indicating whether or not a value can be dereferenced.
(dissoc-in m [k & ks])(ensure-string v)(fmax f maximum)Given a function that returns a number, ensure that the result is never more than the specified value
Given a function that returns a number, ensure that the result is never more than the specified value
(fmin f minimum)Given a function that returns a number, ensure that the result is never less than the specified value
Given a function that returns a number, ensure that the result is never less than the specified value
(format msg & args)(fscalar f)Given a function that expects something sequential as the first argument, returns a function that, if passed something that isn't sequential, creates a new vector, adds the first arg to it, then applies the function
Given a function that expects something sequential as the first argument, returns a function that, if passed something that isn't sequential, creates a new vector, adds the first arg to it, then applies the function
(index-by key-fn coll)(mkstr base length)Creates a new string be repeating the specifed based the specified number of times
Creates a new string be repeating the specifed based the specified number of times
(one? coll)(parse-bool value)(pattern? x)(presence v)(present? v)(safe-deref v)(safe-nth col index)(update-in-if m k-path f & args)Performs an update-in if the key already exists in the map.
Performs an update-in if the key already exists in the map.
(uuid)(uuid value)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |