dgknght.app-lib.dom


bodycljs

(body)

bounding-client-rectcljs

(bounding-client-rect elem)
(bounding-client-rect elem {:keys [as-clojure?]})

checked?cljs

(checked? event)

ctrl-key?cljs

(ctrl-key? event)

Return a boolean value indicating whether or not the event indicates the control key was pressed

Return a boolean value indicating whether or not the event
indicates the control key was pressed
raw docstring

debouncecljs

(debounce f & [timeout])

Accepts a function and returns a function that will execute the given function after a delay (300 milliseconds unless otherwise specified) if the function is not invoked again during the delay (in which case case the timer starts again and the given fn invoked after the delay).

Accepts a function and returns a function that will execute the given
function after a delay (300 milliseconds unless otherwise specified) if
the function is not invoked again during the delay (in which case case
the timer starts again and the given fn invoked after the delay).
raw docstring

enter?cljs

(enter? event)

Return a boolean value indicating whether or not the event represents a press of the enter key

Return a boolean value indicating whether or not the event
represents a press of the enter key
raw docstring

get-stylecljs

(get-style id-or-elem k)

key-codecljs

(key-code event)

Get a keyword representing the keycode of the DOM event

Get a keyword representing the keycode of the DOM event
raw docstring

prevent-defaultcljs

(prevent-default e)

Instruct the DOM event that the default behavior should be suppressed.

Instruct the DOM event that the default behavior should be suppressed.
raw docstring

set-attributecljs

(set-attribute elem a-name a-value)

set-focuscljs

(set-focus id)

set-stylecljs

(set-style id-or-elem k v)

shift-key?cljs

(shift-key? event)

Return a boolean value indicating whether or not the event indicates the shift key was pressed

Return a boolean value indicating whether or not the event
indicates the shift key was pressed
raw docstring

tab?cljs

(tab? event)

Return a boolean value indicating whether or not the event represents a press of the tab key

Return a boolean value indicating whether or not the event
represents a press of the tab key
raw docstring

targetcljs

(target event)

valuecljs

(value elem)

cljdoc builds & hosts documentation for Clojure/Script libraries