dgknght.app-lib.forms-validation


->captionclj/s

(->caption field)

add-rulesclj/s

(add-rules model field rules)

get-rulesclj/s

(get-rules model)
(get-rules model field)

resetclj/s

(reset model)

rule-xfclj/smultimethod


set-custom-validityclj/s

(set-custom-validity event msg)
(set-custom-validity event model field)

valid?clj/s

(valid? model)

validateclj/s

(validate model)
(validate model field)
(validate model field rules)

Applies validation rules configured in the models and returns a channel from which the model can be retrieved post validation.

The one argument arity also sets a flag in the data indicating that the entire model has been validated.

If no validation rules are specified for the model, nil is returned.

Applies validation rules configured in the models and
returns a channel from which the model can be retrieved post validation.

The one argument arity also sets a flag in the data indicating
that the entire model has been validated.

If no validation rules are specified for the model, nil is returned.
raw docstring

validated?clj/s

(validated? model)
(validated? model value)

validation-handlerclj/s

(validation-handler rules model field)

validation-msgclj/s

(validation-msg model)
(validation-msg model field)
(validation-msg model field rule-key)
(validation-msg model field rule-key msg)

validatorclj/s

(validator field rules)

cljdoc builds & hosts documentation for Clojure/Script libraries