(install-mock-dispatcher! v)Ensures the root binding of the given http request Var is a thread-aware dispatcher, installed at most once. Threads with no registered mocks fall through to the Var's original implementation, so real requests from unrelated threads are unaffected.
Ensures the root binding of the given http request Var is a thread-aware dispatcher, installed at most once. Threads with no registered mocks fall through to the Var's original implementation, so real requests from unrelated threads are unaffected.
(parse-query-string {:keys [query-string] :as m})(register-mocks! calls mocks)(request-handler calls mocks)(unregister-mocks!)(with-web-mocks bindings mocks-map & body)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |